==> agrosyst-cli-1.4.5-sources.jar: fr/inra/agrosyst/services/pz0import/growingsystem/GrowingSystemImportDto.java <==
package fr.inra.agrosyst.services.pz0import.growingsystem;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: GrowingSystemImportDto.java 4748 2015-02-03 09:28:19Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.5/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/growingsystem/GrowingSystemImportDto.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.GrowingSystemImpl;

/**
 *  
 * @author eancelet
 *  
 */
public class GrowingSystemImportDto extends GrowingSystemImpl {

    private static final long serialVersionUID = 8435193675746925772L;

    public static final String PROPERTY_ID = "id";
    public static final String PROPERTY_GROWINGPLAN_ID="growingPlanId";
    public static final String PROPERTY_TYPE_AGRICULTURE_ID="typeAgricultureId";


    protected String id;
    protected String growingPlanId;
    protected String typeAgricultureId;

    protected String sectorImporterValue;
    protected String categoryStrategyImporterValue;
    
    public String getGrowingPlanId() {
        return growingPlanId;
    }

    public void setGrowingPlanId(String growingPlanId) {
        this.growingPlanId = growingPlanId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTypeAgricultureId() {
        return typeAgricultureId;
    }

    public void setTypeAgricultureId(String typeAgricultureId) {
        this.typeAgricultureId = typeAgricultureId;
    }

    public String getSectorImporterValue() {
        return sectorImporterValue;
    }

    public void setSectorImporterValue(String sectorImporterValue) {
        this.sectorImporterValue = sectorImporterValue;
    }

    public String getCategoryStrategyImporterValue() {
        return categoryStrategyImporterValue;
    }

    public void setCategoryStrategyImporterValue(String categoryStrategyImporterValue) {
        this.categoryStrategyImporterValue = categoryStrategyImporterValue;
    }
}

==> agrosyst-cli-1.4.6-sources.jar: fr/inra/agrosyst/services/pz0import/growingsystem/GrowingSystemImportDto.java <==
package fr.inra.agrosyst.services.pz0import.growingsystem;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: GrowingSystemImportDto.java 4748 2015-02-03 09:28:19Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/1.4.6/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/growingsystem/GrowingSystemImportDto.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.GrowingSystemImpl;

/**
 *  
 * @author eancelet
 *  
 */
public class GrowingSystemImportDto extends GrowingSystemImpl {

    private static final long serialVersionUID = 8435193675746925772L;

    public static final String PROPERTY_ID = "id";
    public static final String PROPERTY_GROWINGPLAN_ID="growingPlanId";
    public static final String PROPERTY_TYPE_AGRICULTURE_ID="typeAgricultureId";


    protected String id;
    protected String growingPlanId;
    protected String typeAgricultureId;

    protected String sectorImporterValue;
    protected String categoryStrategyImporterValue;
    
    public String getGrowingPlanId() {
        return growingPlanId;
    }

    public void setGrowingPlanId(String growingPlanId) {
        this.growingPlanId = growingPlanId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTypeAgricultureId() {
        return typeAgricultureId;
    }

    public void setTypeAgricultureId(String typeAgricultureId) {
        this.typeAgricultureId = typeAgricultureId;
    }

    public String getSectorImporterValue() {
        return sectorImporterValue;
    }

    public void setSectorImporterValue(String sectorImporterValue) {
        this.sectorImporterValue = sectorImporterValue;
    }

    public String getCategoryStrategyImporterValue() {
        return categoryStrategyImporterValue;
    }

    public void setCategoryStrategyImporterValue(String categoryStrategyImporterValue) {
        this.categoryStrategyImporterValue = categoryStrategyImporterValue;
    }
}
